@@ -12,9 +12,9 @@ UI::Various::Radio - general radio button widget of L<UI::Various>
     my $main = UI::Various::main();
     my $variable = 0;
     $main->window(...
-                  UI::Various::Radio->new(buttons => {1 => 'One',
+                  UI::Various::Radio->new(buttons => [1 => 'One',
                                                       2 => 'Two',
-                                                      3 => 'Three'}),
+                                                      3 => 'Three']),
                   ...);
     $main->mainloop();
 
@@ -48,7 +48,7 @@ no indirect 'fatal';
 no multidimensional;
 use warnings 'once';
 
-our $VERSION = '0.33';
+our $VERSION = '0.34';
 
 use UI::Various::core;
 use UI::Various::widget;
