@@ -32,7 +32,7 @@ no indirect 'fatal';
 no multidimensional;
 use warnings 'once';
 
-our $VERSION = '0.33';
+our $VERSION = '0.34';
 
 use UI::Various::core;
 use UI::Various::Button;
@@ -124,13 +124,8 @@ the rectangular text box for UI element
 sub _show($$$$)
 {
     my ($self, $prefix, $width, $height) = @_;
-    # smaller own width overwrites derived width from environment:
-    my $w = $width - 2;		# - 2 chars decoration
-    $w = $self->{width}  if  defined $self->{width}  and  $self->{width} < $w;
-    local $_ = $self->_format($prefix, $D{BL}, '', $self->text, '', $D{BR},
-			      $w, $height);
-    $w < $width - 2  and  $_ .= ' ' x ($width - 2 - $w);
-    return $_;
+    return $self->_format($prefix, $D{BL}, '', $self->text, '', $D{BR},
+			  $width - 2, $height);		# - 2 chars decoration
 }
 
 #########################################################################
