@@ -59,7 +59,7 @@ no indirect 'fatal';
 no multidimensional;
 use warnings 'once';
 
-our $VERSION = '0.33';
+our $VERSION = '0.34';
 
 use UI::Various::core;
 
@@ -208,7 +208,7 @@ sub dump($;$)
 
     for my $key (sort keys %$self)
     {
-	next if $key =~ m/^(_active|_active_index|parent|_selected)$/;
+	next if $key =~ m/^(_active|_active_index|_button_.*|parent|_selected)$/;
 	next if $key =~ m/^(children)$/  and  $type =~ m/::(Box|FileSelect)$/;
 	$dump .= $indent . $key . ':';
 	my $ref = ref($self->{$key});
@@ -228,11 +228,14 @@ sub dump($;$)
 		{
 		    foreach (@{$element})
 		    {
+			next unless defined $_;
 			$dump .= $indent . '  ' . $_ . ':';
 			if (ref($_) =~ m/^UI::Various::/)
 			{
 			    $dump .= "\n" . $_->dump($level + 2);
 			}
+			elsif (ref($_) eq 'ARRAY')
+			{   $dump .= " @$_\n";   }
 			else
 			{   $dump .= $_ . "\n";   }
 		    }
